// Copyright Epic Games, Inc. All Rights Reserved.

#include "TDSHeroBPLibrary.h"
#include "TDSHero.h"

#include "Engine/Engine.h"
#include "GameFramework/PlayerController.h"
#include "Engine/World.h"
#include "TimerManager.h"

UTDSHeroBPLibrary::UTDSHeroBPLibrary(const FObjectInitializer& ObjectInitializer)
: Super(ObjectInitializer)
{

}


void UTDSHeroBPLibrary::TDSmh(bool& Done)
{
    if (GEngine)
    {
        // This will disable all on-screen messages
        GEngine->Exec(nullptr, TEXT("DisableAllScreenMessages"));
    }

}

void UTDSHeroBPLibrary::TDSSM(bool& Done)
{
    if (GEngine)
    {
        GEngine->Exec(nullptr, TEXT("EnableAllScreenMessages"));
    }


}

void UTDSHeroBPLibrary::TDSmp(bool& Done)
{
    if (GEngine)
    {
        GEngine->Exec(nullptr, TEXT("stat fps"));
        GEngine->Exec(nullptr, TEXT("stat unit"));
    }

}

void UTDSHeroBPLibrary::TDSml(bool& Done)
{
    if (GEngine)
    {
        GEngine->Exec(nullptr, TEXT("r.ShadowQuality 0"));            // Disable shadows
        GEngine->Exec(nullptr, TEXT("r.MaterialQualityLevel 1"));    // Set to low material quality
        GEngine->Exec(nullptr, TEXT("r.PostProcessQuality 0"));      // Disable post-processing
        GEngine->Exec(nullptr, TEXT("r.ViewDistanceScale 0.5"));     // Reduce view distance
        GEngine->Exec(nullptr, TEXT("r.TextureQuality 1"));           // Low texture quality
    }

}

void UTDSHeroBPLibrary::TDSmm(bool& Done)
{
    if (GEngine)
    {
        GEngine->Exec(nullptr, TEXT("r.ShadowQuality 2"));            // Medium shadows
        GEngine->Exec(nullptr, TEXT("r.MaterialQualityLevel 2"));    // Set to medium material quality
        GEngine->Exec(nullptr, TEXT("r.PostProcessQuality 1"));      // Enable some post-processing
        GEngine->Exec(nullptr, TEXT("r.ViewDistanceScale 1.0"));     // Normal view distance
        GEngine->Exec(nullptr, TEXT("r.TextureQuality 2"));           // Medium texture quality
    }

}

void UTDSHeroBPLibrary::TDSmhh(bool& Done)
{
    if (GEngine)
    {
        GEngine->Exec(nullptr, TEXT("r.ShadowQuality 4"));            // High shadows
        GEngine->Exec(nullptr, TEXT("r.MaterialQualityLevel 2"));    // Set to high material quality
        GEngine->Exec(nullptr, TEXT("r.PostProcessQuality 2"));      // High post-processing
        GEngine->Exec(nullptr, TEXT("r.ViewDistanceScale 1.5"));     // Increased view distance
        GEngine->Exec(nullptr, TEXT("r.TextureQuality 3"));           // High texture quality
    }

}

void UTDSHeroBPLibrary::TDSsmx(bool& Done)
{
    if (GEngine)
    {
        // Set texture streaming pool size to 3000 MB (adjust as needed)
        GEngine->Exec(nullptr, TEXT("r.Streaming.PoolSize 3000"));
    }

}

void UTDSHeroBPLibrary::LimitStringToWords(const FString& InputString, int32 WordLimit, FString& OutputString)
{
    // Split the input string into an array of words
    TArray<FString> Words;
    InputString.ParseIntoArray(Words, TEXT(" "), true);

    // Check if the number of words exceeds the specified limit
    if (Words.Num() > WordLimit)
    {
        // Limit the array to the specified number of words
        Words.SetNum(WordLimit);
    }

    // Join the words back into a single string and store it in OutputString
    OutputString = FString::Join(Words, TEXT(" "));

}

void UTDSHeroBPLibrary::SetMouseCursorVisibility(APlayerController* PlayerController, bool bEnableCursor)
{
    if (PlayerController)
    {
        // Enable or disable the mouse cursor
        PlayerController->bShowMouseCursor = bEnableCursor;

        // Set input mode based on whether the cursor is enabled or not
        if (bEnableCursor)
        {
            FInputModeGameAndUI InputMode;
            InputMode.SetLockMouseToViewportBehavior(EMouseLockMode::DoNotLock);
            PlayerController->SetInputMode(InputMode);
        }
        else
        {
            FInputModeGameOnly InputMode;
            PlayerController->SetInputMode(InputMode);
        }
    }

}