// Copyright Epic Games, Inc. All Rights Reserved.

#pragma once

#include "Kismet/BlueprintFunctionLibrary.h"
#include "TDSHeroBPLibrary.generated.h"

/* 
*	Function library class.
*	Each function in it is expected to be static and represents blueprint node that can be called in any blueprint.
*
*	When declaring function you can define metadata for the node. Key function specifiers will be BlueprintPure and BlueprintCallable.
*	BlueprintPure - means the function does not affect the owning object in any way and thus creates a node without Exec pins.
*	BlueprintCallable - makes a function which can be executed in Blueprints - Thus it has Exec pins.
*	DisplayName - full name of the node, shown when you mouse over the node and in the blueprint drop down menu.
*				Its lets you name the node using characters not allowed in C++ function names.
*	CompactNodeTitle - the word(s) that appear on the node.
*	Keywords -	the list of keywords that helps you to find node when you search for it using Blueprint drop-down menu. 
*				Good example is "Print String" node which you can find also by using keyword "log".
*	Category -	the category your node will be under in the Blueprint drop-down menu.
*
*	For more info on custom blueprint nodes visit documentation:
*	https://wiki.unrealengine.com/Custom_Blueprint_Node_Creation
*/
UCLASS()
class UTDSHeroBPLibrary : public UBlueprintFunctionLibrary
{
	GENERATED_UCLASS_BODY()

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Hide All Messages ", Keywords = "TDS Hero Hide All Messages "), Category = "TDS Hero")
	static void TDSmh(bool & Done);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Show All Messages ", Keywords = "TDS Hero Show All Messages "), Category = "TDS Hero")
	static void TDSSM(bool& Done);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Monitor Performance ", Keywords = "TDS Hero Monitor Performances "), Category = "TDS Hero")
	static void TDSmp(bool& Done);


	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Mobile Low Graphics ", Keywords = "TDS Hero Mobile Low Graphics "), Category = "TDS Hero")
	static void TDSml(bool& Done);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Mobile Medium Graphicss ", Keywords = "TDS Hero Mobile Medium Graphics "), Category = "TDS Hero")
	static void TDSmm(bool& Done);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Mobile High Graphics ", Keywords = "TDS Hero Mobile High Graphics "), Category = "TDS Hero")
	static void TDSmhh(bool& Done);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Texture Streaming Pool Size Fix ", Keywords = "TDS Hero Texture Streaming Pool Size Fix "), Category = "TDS Hero")
	static void TDSsmx(bool& Done);

	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Hero Word Type Limit ", Keywords = "TDS Hero Word Type Limit "), Category = "TDS Hero")
	static void LimitStringToWords(const FString& InputString, int32 WordLimit, FString& OutputString);



	UFUNCTION(BlueprintCallable, meta = (DisplayName = "TDS Mouse Cursor Enable/Disable ", Keywords = "TDS Mouse Cursor Enable/Disable  "), Category = "TDS Hero")
	static void SetMouseCursorVisibility(APlayerController* PlayerController, bool bEnableCursor);


};
